==> dotclear-2.7.zip: dotclear/admin/blog_del.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------

require dirname(__FILE__).'/../inc/admin/prepend.php';

dcPage::checkSuper();

$blog_id = '';
$blog_name = '';

if (!empty($_POST['blog_id']))
{
	try {
		$rs = $core->getBlog($_POST['blog_id']);
	} catch (Exception $e) {
		$core->error->add($e->getMessage());
	}

	if ($rs->isEmpty()) {
		$core->error->add(__('No such blog ID'));
	} else {
		$blog_id = $rs->blog_id;
		$blog_name = $rs->blog_name;
	}
}

# Delete the blog
if (!$core->error->flag() && $blog_id && !empty($_POST['del']))
{
	if (!$core->auth->checkPassword(crypt::hmac(DC_MASTER_KEY,$_POST['pwd']))) {
		$core->error->add(__('Password verification failed'));
	} else {
		try {
			$core->delBlog($blog_id);
			dcPage::addSuccessNotice(sprintf(__('Blog "%s" successfully deleted'), html::escapeHTML($blog_name)));

			http::redirect($core->adminurl->get("admin.blogs"));
		} catch (Exception $e) {
			$core->error->add($e->getMessage());
		}
	}
}

dcPage::open(__('Delete a blog'),'',
	dcPage::breadcrumb(
		array(
			__('System') => '',
			__('Blogs') => $core->adminurl->get("admin.blogs"),
			__('Delete a blog') => ''
		))
);

if (!$core->error->flag())
{
	echo
	'<div class="warning-msg"><p><strong>'.__('Warning').'</strong></p>'.
	'<p>'.sprintf(__('You are about to delete the blog %s. Every entry, comment and category will be deleted.'),
	'<strong>'.$blog_id.' ('.$blog_name.')</strong>').'</p></div>'.
	'<p>'.__('Please give your password to confirm the blog deletion.').'</p>';

	echo
	'<form action="'.$core->adminurl->get("admin.blog.del").'" method="post">'.
	'<div>'.$core->formNonce().'</div>'.
	'<p><label for="pwd">'.__('Your password:').'</label> '.
	form::password('pwd',20,255).'</p>'.
	'<p><input type="submit" class="delete" name="del" value="'.__('Delete this blog').'" />'.
	form::hidden('blog_id',$blog_id).'</p>'.
	'</form>';
}

dcPage::close();

==> dotclear-2.13.zip: dotclear/admin/blog_del.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------

require dirname(__FILE__).'/../inc/admin/prepend.php';

dcPage::checkSuper();

$blog_id = '';
$blog_name = '';

if (!empty($_POST['blog_id']))
{
	try {
		$rs = $core->getBlog($_POST['blog_id']);
	} catch (Exception $e) {
		$core->error->add($e->getMessage());
	}

	if ($rs->isEmpty()) {
		$core->error->add(__('No such blog ID'));
	} else {
		$blog_id = $rs->blog_id;
		$blog_name = $rs->blog_name;
	}
}

# Delete the blog
if (!$core->error->flag() && $blog_id && !empty($_POST['del']))
{
	if (!$core->auth->checkPassword($_POST['pwd'])) {
		$core->error->add(__('Password verification failed'));
	} else {
		try {
			$core->delBlog($blog_id);
			dcPage::addSuccessNotice(sprintf(__('Blog "%s" successfully deleted'), html::escapeHTML($blog_name)));

			$core->adminurl->redirect("admin.blogs");
		} catch (Exception $e) {
			$core->error->add($e->getMessage());
		}
	}
}

dcPage::open(__('Delete a blog'),'',
	dcPage::breadcrumb(
		array(
			__('System') => '',
			__('Blogs') => $core->adminurl->get("admin.blogs"),
			__('Delete a blog') => ''
		))
);

if (!$core->error->flag())
{
	echo
	'<div class="warning-msg"><p><strong>'.__('Warning').'</strong></p>'.
	'<p>'.sprintf(__('You are about to delete the blog %s. Every entry, comment and category will be deleted.'),
	'<strong>'.$blog_id.' ('.$blog_name.')</strong>').'</p></div>'.
	'<p>'.__('Please give your password to confirm the blog deletion.').'</p>';

	echo
	'<form action="'.$core->adminurl->get("admin.blog.del").'" method="post">'.
	'<div>'.$core->formNonce().'</div>'.
	'<p><label for="pwd">'.__('Your password:').'</label> '.
	form::password('pwd',20,255).'</p>'.
	'<p><input type="submit" class="delete" name="del" value="'.__('Delete this blog').'" />'.
	form::hidden('blog_id',$blog_id).'</p>'.
	'</form>';
}

dcPage::close();
